@@ -39,14 +39,8 @@
  *   Abramowitz and Stegun, Handbook of Mathematical Functions, "Inverse
  *   Circular Functions in Terms of Real and Imaginary Parts", Formulas
  *   4.4.37, 4.4.38, 4.4.39
- *
- * FIXME: The functions using gsl_complex_inverse will overflow in
- * intermediate expressions like sinh(I), which are then
- * reciprocated. The overflow could be avoided by rearranging the
- * expression, as done for tan(z).  
  */
 
-
 #include <config.h>
 #include <math.h>
 #include <gsl/gsl_math.h>
@@ -57,6 +51,7 @@
  * Complex numbers
  **********************************************************************/
 
+#ifndef HIDE_INLINE_STATIC
 gsl_complex
 gsl_complex_rect (double x, double y)
 {				/* return z = x + i y */
@@ -64,6 +59,7 @@ gsl_complex_rect (double x, double y)
   GSL_SET_COMPLEX (&z, x, y);
   return z;
 }
+#endif
 
 gsl_complex
 gsl_complex_polar (double r, double theta)
@@ -227,6 +223,22 @@ gsl_complex_div (gsl_complex a, gsl_complex b)
   return z;
 }
 
+gsl_complex
+gsl_complex_div_real (gsl_complex a, double x)
+{				/* z=a/x */
+  gsl_complex z;
+  GSL_SET_COMPLEX (&z, GSL_REAL (a) / x, GSL_IMAG (a) / x);
+  return z;
+}
+
+gsl_complex
+gsl_complex_div_imag (gsl_complex a, double y)
+{				/* z=a/(iy) */
+  gsl_complex z;
+  GSL_SET_COMPLEX (&z, GSL_IMAG (a) / y,  - GSL_REAL (a) / y);
+  return z;
+}
+
 gsl_complex
 gsl_complex_conjugate (gsl_complex a)
 {				/* z=conj(a) */
