@@ -21,27 +21,27 @@
 #define __GSL_CONST_CGS__
 
 #define GSL_CONST_CGS_SPEED_OF_LIGHT (2.99792458e10) /* cm / s */
-#define GSL_CONST_CGS_GRAVITATIONAL_CONSTANT (6.67259e-8) /* cm^3 / g s^2 */
-#define GSL_CONST_CGS_PLANCKS_CONSTANT_H (6.6260755e-27) /* g cm^2 / s */
-#define GSL_CONST_CGS_PLANCKS_CONSTANT_HBAR (1.05457266913e-27) /* g cm^2 / s */
+#define GSL_CONST_CGS_GRAVITATIONAL_CONSTANT (6.673e-8) /* cm^3 / g s^2 */
+#define GSL_CONST_CGS_PLANCKS_CONSTANT_H (6.62606876e-27) /* g cm^2 / s */
+#define GSL_CONST_CGS_PLANCKS_CONSTANT_HBAR (1.05457159642e-27) /* g cm^2 / s */
 #define GSL_CONST_CGS_VACUUM_PERMEABILITY (1.25663706144e-1) /* cm g / A^2 s^2 */
-#define GSL_CONST_CGS_ASTRONOMICAL_UNIT (1.495979e13) /* cm */
+#define GSL_CONST_CGS_ASTRONOMICAL_UNIT (1.49597870691e13) /* cm */
 #define GSL_CONST_CGS_LIGHT_YEAR (9.46053620707e17) /* cm */
-#define GSL_CONST_CGS_PARSEC (3.08567818589e18) /* cm */
+#define GSL_CONST_CGS_PARSEC (3.08567758135e18) /* cm */
 #define GSL_CONST_CGS_GRAV_ACCEL (9.80665e2) /* cm / s^2 */
-#define GSL_CONST_CGS_ELECTRON_VOLT (1.60217733e-12) /* g cm^2 / s^2 */
-#define GSL_CONST_CGS_MASS_ELECTRON (9.10938961969e-28) /* g */
-#define GSL_CONST_CGS_MASS_MUON (1.88353269879e-25) /* g */
-#define GSL_CONST_CGS_MASS_PROTON (1.67262307095e-24) /* g */
-#define GSL_CONST_CGS_MASS_NEUTRON (1.67492862142e-24) /* g */
-#define GSL_CONST_CGS_RYDBERG (2.17987412173e-11) /* g cm^2 / s^2 */
-#define GSL_CONST_CGS_BOLTZMANN (1.3806513e-16) /* g cm^2 / K s^2 */
-#define GSL_CONST_CGS_BOHR_MAGNETON (9.27401542715e-20) /* A cm^2 */
-#define GSL_CONST_CGS_NUCLEAR_MAGNETON (5.05078658357e-23) /* A cm^2 */
-#define GSL_CONST_CGS_ELECTRON_MAGNETIC_MOMENT (9.28477005945e-20) /* A cm^2 */
-#define GSL_CONST_CGS_PROTON_MAGNETIC_MOMENT (1.41060761072e-22) /* A cm^2 */
-#define GSL_CONST_CGS_MOLAR_GAS (8.31447086363e7) /* g cm^2 / K mol s^2 */
-#define GSL_CONST_CGS_STANDARD_GAS_VOLUME (2.2413992e4) /* cm^3 / mol */
+#define GSL_CONST_CGS_ELECTRON_VOLT (1.602176462e-12) /* g cm^2 / s^2 */
+#define GSL_CONST_CGS_MASS_ELECTRON (9.10938188e-28) /* g */
+#define GSL_CONST_CGS_MASS_MUON (1.88353109e-25) /* g */
+#define GSL_CONST_CGS_MASS_PROTON (1.67262158e-24) /* g */
+#define GSL_CONST_CGS_MASS_NEUTRON (1.67492716e-24) /* g */
+#define GSL_CONST_CGS_RYDBERG (2.17987190389e-11) /* g cm^2 / s^2 */
+#define GSL_CONST_CGS_BOLTZMANN (1.3806503e-16) /* g cm^2 / K s^2 */
+#define GSL_CONST_CGS_BOHR_MAGNETON (9.27400899e-20) /* A cm^2 */
+#define GSL_CONST_CGS_NUCLEAR_MAGNETON (5.05078317e-23) /* A cm^2 */
+#define GSL_CONST_CGS_ELECTRON_MAGNETIC_MOMENT (9.28476362e-20) /* A cm^2 */
+#define GSL_CONST_CGS_PROTON_MAGNETIC_MOMENT (1.410606633e-22) /* A cm^2 */
+#define GSL_CONST_CGS_MOLAR_GAS (8.314472e7) /* g cm^2 / K mol s^2 */
+#define GSL_CONST_CGS_STANDARD_GAS_VOLUME (2.2710981e4) /* cm^3 / mol */
 #define GSL_CONST_CGS_MINUTE (6e1) /* s */
 #define GSL_CONST_CGS_HOUR (3.6e3) /* s */
 #define GSL_CONST_CGS_DAY (8.64e4) /* s */
@@ -80,7 +80,7 @@
 #define GSL_CONST_CGS_UK_TON (1.0160469088e6) /* g */
 #define GSL_CONST_CGS_TROY_OUNCE (3.1103475e1) /* g */
 #define GSL_CONST_CGS_CARAT (2e-1) /* g */
-#define GSL_CONST_CGS_UNIFIED_ATOMIC_MASS (1.6605402e-24) /* g */
+#define GSL_CONST_CGS_UNIFIED_ATOMIC_MASS (1.66053873e-24) /* g */
 #define GSL_CONST_CGS_GRAM_FORCE (9.80665e2) /* cm g / s^2 */
 #define GSL_CONST_CGS_POUND_FORCE (4.44822161526e5) /* cm g / s^2 */
 #define GSL_CONST_CGS_KILOPOUND_FORCE (4.44822161526e8) /* cm g / s^2 */
@@ -94,12 +94,12 @@
 #define GSL_CONST_CGS_TORR (1.33322368421e3) /* g / cm s^2 */
 #define GSL_CONST_CGS_METER_OF_MERCURY (1.33322368421e6) /* g / cm s^2 */
 #define GSL_CONST_CGS_INCH_OF_MERCURY (3.38638815789e4) /* g / cm s^2 */
-#define GSL_CONST_CGS_INCH_OF_WATER (2.4884e3) /* g / cm s^2 */
+#define GSL_CONST_CGS_INCH_OF_WATER (2.490889e3) /* g / cm s^2 */
 #define GSL_CONST_CGS_PSI (6.89475729317e4) /* g / cm s^2 */
 #define GSL_CONST_CGS_POISE (1e0) /* g / cm s */
 #define GSL_CONST_CGS_STOKES (1e0) /* cm^2 / s */
-#define GSL_CONST_CGS_FARADAY (9.6485308989e4) /* A s / mol */
-#define GSL_CONST_CGS_ELECTRON_CHARGE (1.60217733e-19) /* A s */
+#define GSL_CONST_CGS_FARADAY (9.6485341472e4) /* A s / mol */
+#define GSL_CONST_CGS_ELECTRON_CHARGE (1.602176462e-19) /* A s */
 #define GSL_CONST_CGS_GAUSS (1e-1) /* g / A s^2 */
 #define GSL_CONST_CGS_STILB (1e0) /* cd / cm^2 */
 #define GSL_CONST_CGS_LUMEN (1e0) /* cd sr */
@@ -114,5 +114,9 @@
 #define GSL_CONST_CGS_SOLAR_MASS (1.98892e33) /* g */
 #define GSL_CONST_CGS_BOHR_RADIUS (5.291772083e-9) /* cm */
 #define GSL_CONST_CGS_VACUUM_PERMITTIVITY (8.854187817e-21) /* A^2 s^4 / g cm^3 */
+#define GSL_CONST_CGS_NEWTON (1e5) /* cm g / s^2 */
+#define GSL_CONST_CGS_DYNE (1e0) /* cm g / s^2 */
+#define GSL_CONST_CGS_JOULE (1e7) /* g cm^2 / s^2 */
+#define GSL_CONST_CGS_ERG (1e0) /* g cm^2 / s^2 */
 
 #endif /* __GSL_CONST_CGS__ */
