@@ -33,7 +33,7 @@
 #include <gsl/gsl_math.h>
 #include <gsl/gsl_vector.h>
 #include <gsl/gsl_matrix.h>
-#include "gsl_eigen.h"
+#include <gsl/gsl_eigen.h>
 
 #define REAL double
 
