@@ -18,6 +18,7 @@
  */
 
 #include <config.h>
+#include <stdlib.h>
 #include <stdio.h>
 #include <gsl/gsl_histogram2d.h>
 #include <gsl/gsl_test.h>
@@ -191,7 +192,7 @@ main (void)
 
   gsl_histogram2d_free (h);
 
-  return gsl_test_summary ();
+  exit (gsl_test_summary ());
 }
 
 
