@@ -1,3 +1,22 @@
+/* integration/qpsrt.c
+ * 
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000 Brian Gough
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
 static inline void 
 qpsrt (gsl_integration_workspace * workspace);
 
@@ -58,7 +77,10 @@ void qpsrt (gsl_integration_workspace * workspace)
   
   i = i_nrmax + 1 ;
   
-  while (errmax < elist[order[i]] && i < top)
+  /* The order of the tests in the following line is important to
+     prevent a segmentation fault */
+
+  while (i < top && errmax < elist[order[i]])
     {
       order[i-1] = order[i] ;
       i++ ;
@@ -72,7 +94,7 @@ void qpsrt (gsl_integration_workspace * workspace)
   
   k = top - 1 ;
   
-  while (errmin >= elist[order[k]] && k > i - 2)
+  while (k > i - 2 && errmin >= elist[order[k]])
     {
       order[k+1] = order[k] ;
       k-- ;
