@@ -31,7 +31,7 @@
 #include <gsl/gsl_matrix.h>
 #include <gsl/gsl_blas.h>
 
-#include "gsl_linalg.h"
+#include <gsl/gsl_linalg.h>
 
 int
 gsl_linalg_balance_columns (gsl_matrix * A, gsl_vector * D)
