@@ -84,7 +84,7 @@ gsl_linalg_SV_decomp (gsl_matrix * A, gsl_matrix * V, gsl_vector * S,
   {
     gsl_vector_view f = gsl_vector_subvector (work, 0, K - 1);
     
-    /* bidiagonalize matrix A, unpack A into U V S */
+    /* bidiagonalize matrix A, unpack A into U S V */
     
     gsl_linalg_bidiag_decomp (A, S, &f.vector);
     gsl_linalg_bidiag_unpack2 (A, S, &f.vector, V);
@@ -160,15 +160,16 @@ gsl_linalg_SV_decomp (gsl_matrix * A, gsl_matrix * V, gsl_vector * S,
   
   for (i = 0; i < K; i++)
     {
-      double Si = gsl_vector_get (S, i);
+      double S_max = gsl_vector_get (S, i);
       size_t i_max = i;
       
       for (j = i + 1; j < K; j++)
         {
           double Sj = gsl_vector_get (S, j);
           
-          if (Sj > Si)
+          if (Sj > S_max)
             {
+              S_max = Sj;
 	      i_max = j;
 	    }
 	}
