@@ -21,6 +21,7 @@
 #define __GSL_MATRIX_SHORT_H__
 
 #include <stdlib.h>
+#include <gsl/gsl_types.h>
 #include <gsl/gsl_errno.h>
 #include <gsl/gsl_vector_short.h>
 
@@ -236,7 +237,7 @@ int gsl_matrix_short_get_col(gsl_vector_short * v, const gsl_matrix_short * m, c
 int gsl_matrix_short_set_row(gsl_matrix_short * m, const size_t i, const gsl_vector_short * v);
 int gsl_matrix_short_set_col(gsl_matrix_short * m, const size_t j, const gsl_vector_short * v);
 
-extern int gsl_check_range ;
+GSL_VAR int gsl_check_range ;
 
 /* inline functions if you are using GCC */
 
