@@ -21,6 +21,7 @@
 #define __GSL_MATRIX_UINT_H__
 
 #include <stdlib.h>
+#include <gsl/gsl_types.h>
 #include <gsl/gsl_errno.h>
 #include <gsl/gsl_vector_uint.h>
 
@@ -236,7 +237,7 @@ int gsl_matrix_uint_get_col(gsl_vector_uint * v, const gsl_matrix_uint * m, cons
 int gsl_matrix_uint_set_row(gsl_matrix_uint * m, const size_t i, const gsl_vector_uint * v);
 int gsl_matrix_uint_set_col(gsl_matrix_uint * m, const size_t j, const gsl_vector_uint * v);
 
-extern int gsl_check_range ;
+GSL_VAR int gsl_check_range ;
 
 /* inline functions if you are using GCC */
 
