@@ -40,11 +40,11 @@ typedef struct
   }
 goldensection_state_t;
 
-static int goldensection_init (void * vstate, gsl_function * f, double minimum, double f_minimum, double x_lower, double f_lower, double x_upper, double f_upper);
-static int goldensection_iterate (void * vstate, gsl_function * f, double * minimum, double * f_minimum, double * x_lower, double * f_lower, double * x_upper, double * f_upper);
+static int goldensection_init (void * vstate, gsl_function * f, double x_minimum, double f_minimum, double x_lower, double f_lower, double x_upper, double f_upper);
+static int goldensection_iterate (void * vstate, gsl_function * f, double * x_minimum, double * f_minimum, double * x_lower, double * f_lower, double * x_upper, double * f_upper);
 
 static int
-goldensection_init (void * vstate, gsl_function * f, double minimum, double f_minimum, double x_lower, double f_lower, double x_upper, double f_upper)
+goldensection_init (void * vstate, gsl_function * f, double x_minimum, double f_minimum, double x_lower, double f_lower, double x_upper, double f_upper)
 {
   goldensection_state_t * state = (goldensection_state_t *) vstate;
 
@@ -52,7 +52,7 @@ goldensection_init (void * vstate, gsl_function * f, double minimum, double f_mi
 
   state = 0;
   f = 0;
-  minimum = 0;
+  x_minimum = 0;
   f_minimum = 0;
   x_lower = 0;
   f_lower = 0;
@@ -63,11 +63,11 @@ goldensection_init (void * vstate, gsl_function * f, double minimum, double f_mi
 }
 
 static int
-goldensection_iterate (void * vstate, gsl_function * f, double * minimum, double * f_minimum, double * x_lower, double * f_lower, double * x_upper, double * f_upper)
+goldensection_iterate (void * vstate, gsl_function * f, double * x_minimum, double * f_minimum, double * x_lower, double * f_lower, double * x_upper, double * f_upper)
 {
   goldensection_state_t * state = (goldensection_state_t *) vstate;
 
-  const double x_minimum = *minimum ;
+  const double x_center = *x_minimum ;
   const double x_left = *x_lower ;
   const double x_right = *x_upper ;
 
@@ -75,30 +75,30 @@ goldensection_iterate (void * vstate, gsl_function * f, double * minimum, double
 
   const double golden = 0.3819660; /* golden = (3 - sqrt(5))/2 */
   
-  const double w_lower = (x_minimum - x_left);
-  const double w_upper = (x_right - x_minimum);
+  const double w_lower = (x_center - x_left);
+  const double w_upper = (x_right - x_center);
 
   double x_new, f_new;
 
   state = 0 ; /* avoid warning about unused parameters */
   
-  x_new = x_minimum + golden * ((w_upper > w_lower) ? w_upper : -w_lower) ;
+  x_new = x_center + golden * ((w_upper > w_lower) ? w_upper : -w_lower) ;
 
   SAFE_FUNC_CALL (f, x_new, &f_new);
 
   if (f_new < f_min)
     {
-      *minimum = x_new ;
+      *x_minimum = x_new ;
       *f_minimum = f_new ;
       return GSL_SUCCESS;
     }
-  else if (x_new < x_minimum && f_new > f_min)
+  else if (x_new < x_center && f_new > f_min)
     {
       *x_lower = x_new ;
       *f_lower = f_new ;
       return GSL_SUCCESS;
     }
-  else if (x_new > x_minimum && f_new > f_min)
+  else if (x_new > x_center && f_new > f_min)
     {
       *x_upper = x_new ;
       *f_upper = f_new ;
