@@ -45,6 +45,8 @@ gsl_rng_types_setup (void)
   ADD(gsl_rng_minstd);
   ADD(gsl_rng_mrg);
   ADD(gsl_rng_mt19937);
+  ADD(gsl_rng_mt19937_1999);
+  ADD(gsl_rng_mt19937_1998);
   ADD(gsl_rng_r250);
   ADD(gsl_rng_ran0);
   ADD(gsl_rng_ran1);
@@ -82,6 +84,8 @@ gsl_rng_types_setup (void)
   ADD(gsl_rng_ranmar);
   ADD(gsl_rng_slatec);
   ADD(gsl_rng_taus);
+  ADD(gsl_rng_taus2);
+  ADD(gsl_rng_taus113);
   ADD(gsl_rng_transputer);
   ADD(gsl_rng_tt800);
   ADD(gsl_rng_uni);
