@@ -22,9 +22,9 @@
 #include <config.h>
 #include <gsl/gsl_math.h>
 #include <gsl/gsl_errno.h>
-#include "gsl_sf_gamma.h"
-#include "gsl_sf_psi.h"
-#include "gsl_sf_bessel.h"
+#include <gsl/gsl_sf_gamma.h>
+#include <gsl/gsl_sf_psi.h>
+#include <gsl/gsl_sf_bessel.h>
 
 #include "error.h"
 
