@@ -23,7 +23,7 @@
 
 #include <gsl/gsl_math.h>
 #include <gsl/gsl_errno.h>
-#include "gsl_sf_bessel.h"
+#include <gsl/gsl_sf_bessel.h>
 #include "bessel_amp_phase.h"
 
 /* chebyshev expansions for amplitude and phase
