@@ -23,8 +23,8 @@
 #include <stdlib.h>
 #include <gsl/gsl_math.h>
 #include <gsl/gsl_errno.h>
-#include "gsl_sf_gamma.h"
-#include "gsl_sf_coupling.h"
+#include <gsl/gsl_sf_gamma.h>
+#include <gsl/gsl_sf_coupling.h>
 
 #include "error.h"
 
