@@ -22,12 +22,12 @@
 #include <config.h>
 #include <gsl/gsl_math.h>
 #include <gsl/gsl_errno.h>
-#include "gsl_sf_exp.h"
-#include "gsl_sf_gamma.h"
-#include "gsl_sf_hyperg.h"
-#include "gsl_sf_pow_int.h"
-#include "gsl_sf_zeta.h"
-#include "gsl_sf_fermi_dirac.h"
+#include <gsl/gsl_sf_exp.h>
+#include <gsl/gsl_sf_gamma.h>
+#include <gsl/gsl_sf_hyperg.h>
+#include <gsl/gsl_sf_pow_int.h>
+#include <gsl/gsl_sf_zeta.h>
+#include <gsl/gsl_sf_fermi_dirac.h>
 
 #include "error.h"
 
