@@ -22,11 +22,11 @@
 #include <config.h>
 #include <gsl/gsl_math.h>
 #include <gsl/gsl_errno.h>
-#include "gsl_sf_exp.h"
-#include "gsl_sf_log.h"
-#include "gsl_sf_psi.h"
-#include "gsl_sf_trig.h"
-#include "gsl_sf_gamma.h"
+#include <gsl/gsl_sf_exp.h>
+#include <gsl/gsl_sf_log.h>
+#include <gsl/gsl_sf_psi.h>
+#include <gsl/gsl_sf_trig.h>
+#include <gsl/gsl_sf_gamma.h>
 
 #include "error.h"
 #include "check.h"
@@ -1029,7 +1029,12 @@ gamma_xgthalf(const double x, gsl_sf_result * result)
     result->val = 1.77245385090551602729817;
     result->err = GSL_DBL_EPSILON * result->val;
     return GSL_SUCCESS;
-  }
+  } else if (x <= (FACT_TABLE_MAX + 1.0) && x == floor(x)) {
+    int n = (int) floor (x);
+    result->val = fact_table[n - 1].f;
+    result->err = GSL_DBL_EPSILON * result->val;
+    return GSL_SUCCESS;
+  }    
   else if(fabs(x - 1.0) < 0.01) {
     /* Use series for Gamma[1+eps] - 1/(1+eps).
      */
