@@ -17,9 +17,8 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* Author:  G. Jungman
- * RCS:     $Id: gsl_sf_coulomb.h,v 1.23 2001/04/30 11:20:16 bjg Exp $
- */
+/* Author:  G. Jungman */
+
 #ifndef __GSL_SF_COULOMB_H__
 #define __GSL_SF_COULOMB_H__
 
@@ -121,7 +120,7 @@ int gsl_sf_coulomb_wave_sphF_array(double lam_min, int kmax,
  * [Abramowitz+Stegun 14.1.8, 14.1.9]
  */
 int gsl_sf_coulomb_CL_e(double L, double eta, gsl_sf_result * result);
-int gsl_sf_coulomb_CL_list(double Lmin, int kmax, double eta, double * cl);
+int gsl_sf_coulomb_CL_array(double Lmin, int kmax, double eta, double * cl);
 
 
 __END_DECLS
