@@ -22,9 +22,9 @@
 #include <config.h>
 #include <gsl/gsl_math.h>
 #include <gsl/gsl_errno.h>
-#include "gsl_sf_exp.h"
-#include "gsl_sf_pow_int.h"
-#include "gsl_sf_synchrotron.h"
+#include <gsl/gsl_sf_exp.h>
+#include <gsl/gsl_sf_pow_int.h>
+#include <gsl/gsl_sf_synchrotron.h>
 
 #include "error.h"
 
