@@ -25,14 +25,14 @@
 #include <gsl/gsl_math.h>
 #include <gsl/gsl_errno.h>
 #include <gsl/gsl_machine.h>
-#include "gsl_sf_result.h"
+#include <gsl/gsl_sf_result.h>
 
 double test_sf_frac_diff(double x1, double x2);
 int test_sf_check_result(char * message_buff, gsl_sf_result r, double val, double tol);
+int test_sf_check_val(char * message_buff, double rval, double val, double tol);
 int test_sf_check_return(char * message_buff, int val_return, int expected_return);
 int test_sf_check_result_relax(char * message_buff, gsl_sf_result r, double val, double tol);
 
-
 #define TEST_TOL0  (2.0*GSL_DBL_EPSILON)
 #define TEST_TOL1  (16.0*GSL_DBL_EPSILON)
 #define TEST_TOL2  (256.0*GSL_DBL_EPSILON)
@@ -49,12 +49,15 @@ int test_sf_check_result_relax(char * message_buff, gsl_sf_result r, double val,
 #define TEST_SF_RETBAD  8
 
 int test_sf (gsl_sf_result r, double val_in, double tol, int status, int expect_return, const char * desc);
+int test_sf_val (double val, double val_in, double tol, const char * desc);
 int test_sf_rlx (gsl_sf_result r, double val_in, double tol, int status, int expect_return, const char * desc);
 int test_sf_2 (gsl_sf_result r1, double val1, double tol1, gsl_sf_result r2, double val2, double tol2, int status, int expect_return, const char * desc);
 int test_sf_sgn (gsl_sf_result r, double sgn, double val_in, double tol, double expect_sgn, int status, int expect_return, const char * desc);
 
 #define TEST_SF(stat, func, args, val_in, tol, expect_return) { int status = func args; stat += test_sf(r, val_in, tol, status, expect_return, #func #args); }
 
+#define TEST_SF_VAL(stat, func, args, val_in, tol) { double val = func args; stat += test_sf_val(val, val_in, tol, #func #args); }
+
 #define TEST_SF_RLX(stat, func, args, val_in, tol, expect_return) { int status = func args; stat += test_sf_rlx(r, val_in, tol, status, expect_return, #func #args); }
 
 #define TEST_SF_2(stat, func, args, val1, tol1, val2, tol2, expect_return) { int status = func args; stat += test_sf_2(r1, val1, tol1, r2, val2, tol2, status, expect_return, #func #args); }
