@@ -18,9 +18,13 @@
  */
 
 #include <config.h>
-#include <gsl_version.h>  /* this has to be kept in the top-level
-                             directory due to the way the gsl/ 
-                             subdirectory is build */
+#include <gsl_version.h>
+
+/* This file needs to use the top-level <gsl_version.h> due to the
+   possibility of a VPATH-style build where the original source
+   tree is on read-only filesystem and so will not be picked up
+   by the symlinking comands in gsl/Makefile.am */
+
 
 const char * gsl_version = GSL_VERSION;
 
